# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .time_series_feature_model_geometry import TimeSeriesFeatureModelGeometry
from .time_series_feature_model_id import TimeSeriesFeatureModelId
from .time_series_properties_model import TimeSeriesPropertiesModel


class TimeSeriesFeatureModel(UniversalBaseModel):
    """
    GeoJSON Feature with time-series properties.
    """

    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    type: typing.Literal["Feature"] = "Feature"
    geometry: typing.Optional[TimeSeriesFeatureModelGeometry] = None
    properties: typing.Optional[TimeSeriesPropertiesModel] = None
    id: typing.Optional[TimeSeriesFeatureModelId] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(TimeSeriesFeatureModel)
