# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .time_series_properties_model_static import TimeSeriesPropertiesModelStatic


class TimeSeriesPropertiesModel(UniversalBaseModel):
    """
    Concrete model for OpenAPI schema generation.
    """

    datetimes: typing.List[dt.datetime]
    static: TimeSeriesPropertiesModelStatic

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
