# This file was auto-generated by Fern from our API Definition.

import typing

from .imperial_units import ImperialUnits
from .metric_units import MetricUnits

HourlyWeatherResponseUnits = typing.Union[MetricUnits, ImperialUnits]
